-- indoorAnalogOTHud
-- specialization script for FS 17 vehicles
-- adds indoor analog operating time counter (in hours) hud
-- author: agRush2k
-- modified from mthCounter v 2.0.0.0
-- version 1.0.0.0
-- date: 2018-03-06 (complete: 2018-03-08)

indoorAnalogOTHud = {};

function indoorAnalogOTHud.prerequisitesPresent (specializations)
	return
	SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function indoorAnalogOTHud:load(savegame)
	--total
	self.hundredth = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.hundredth#index"));
	self.tenth = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.tenth#index"));
	self.one = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.one#index"));
	self.ten = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.ten#index"));
	self.hundred = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.hundred#index"));
	self.thousand = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.all.thousand#index"));
	-- in one session
	self.hundredthSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.hundredth#index"));
	self.tenthSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.tenth#index"));
	self.oneSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.one#index"));
	self.tenSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.ten#index"));
	self.hundredSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.hundred#index"));
	self.thousandSession = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.indoorAnalogOTHud.session.thousand#index"));

	if savegame ~= nil then
		self.ot = Utils.getNoNil(getXMLFloat(savegame.xmlFile, savegame.key .. "#operatingTime"), self.operatingTime) * 1000;
		local rotation = 2 * math.pi * self.ot / 3600000;
		if self.hundredth ~= nil then
			setRotation(self.hundredth, rotation * 10, 0, 0);
		end;
		if self.tenth ~= nil then
			setRotation(self.tenth, rotation, 0, 0);
		end;
		if self.one ~= nil then
			setRotation(self.one, rotation / 10, 0, 0);
		end;
		if self.ten ~= nil then
			setRotation(self.ten, rotation / 100, 0, 0);
		end;
		if self.hundred ~= nil then
			setRotation(self.hundred, rotation / 1000, 0, 0);
		end;
		if self.thousand ~= nil then
			setRotation(self.thousand, rotation / 10000, 0, 0);
		end;
	else
		self.ot = 0;
	end;
	print("indoorAnalogOTHud: loaded ('"..self.configFileName.."')");
end;

function indoorAnalogOTHud:delete()
end;

function indoorAnalogOTHud:readStream(streamId, connection)
    self:setMth(streamReadFloat32(streamId), true);
end;

function indoorAnalogOTHud:writeStream(streamId, connection)
end;

function indoorAnalogOTHud:mouseEvent(posX, posY, isDown, isUp, button)
end;

function indoorAnalogOTHud:keyEvent(unicode, sym, modifier, isDown)
end;

function indoorAnalogOTHud:update(dt)
	local sRotx = 2 * math.pi * self.operatingTime / 3600000;
	local sRotx2 = 2 * math.pi * (self.operatingTime - self.ot) / 3600000;
	if self.hundredth ~= nil and self.isMotorStarted then
		setRotation(self.hundredth, sRotx * 10, 0, 0);
	end;
	if self.hundredthSession ~= nil and self.isMotorStarted then
		setRotation(self.hundredthSession, sRotx2 * 10, 0, 0);
	end;
	if self.tenth ~= nil and self.isMotorStarted then
		setRotation(self.tenth, sRotx, 0, 0);
	end;
	if self.tenthSession ~= nil and self.isMotorStarted then
		setRotation(self.tenthSession, sRotx2, 0, 0);
	end;
	if self.one ~= nil and self.isMotorStarted then
		setRotation(self.one, sRotx / 10, 0, 0);
	end;
	if self.oneSession ~= nil and self.isMotorStarted then
		setRotation(self.oneSession, sRotx2 / 10, 0, 0);
	end;
	if self.ten ~= nil and self.isMotorStarted then
		setRotation(self.ten, sRotx / 100, 0, 0);
	end;
	if self.tenSession ~= nil and self.isMotorStarted then
		setRotation(self.tenSession, sRotx2 / 100, 0, 0);
	end;
	if self.hundred ~= nil and self.isMotorStarted then
		setRotation(self.hundred, sRotx / 1000, 0, 0);
	end;
	if self.hundredSession ~= nil and self.isMotorStarted then
		setRotation(self.hundredSession, sRotx2 / 1000, 0, 0);
	end;
	if self.thousand ~= nil and self.isMotorStarted then
		setRotation(self.thousand, sRotx / 10000, 0, 0);
	end;
	if self.thousandSession ~= nil and self.isMotorStarted then
		setRotation(self.thousandSession, sRotx2 / 10000, 0, 0);
	end;
end;

function indoorAnalogOTHud:updateTick(dt)
end;

function indoorAnalogOTHud:draw()
end;